==> orchestra-pvm-4.2.1-sources.jar: org/ow2/orchestra/pvm/internal/job/CommandMessage.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.ow2.orchestra.pvm.internal.job;

import org.ow2.orchestra.pvm.env.Environment;
import org.ow2.orchestra.pvm.internal.cmd.Command;
import org.ow2.orchestra.pvm.internal.jobexecutor.JobDbSession;
import org.ow2.orchestra.pvm.internal.wire.Descriptor;
import org.ow2.orchestra.pvm.internal.wire.WireContext;

/**
 * @author Tom Baeyens
 */
public class CommandMessage extends MessageImpl<Object> {

  private static final long serialVersionUID = 1L;

  public CommandMessage() {
  }

  public CommandMessage(final Descriptor commandDescriptor) {
    this.commandDescriptor = commandDescriptor;
  }

  public Object execute(final Environment environment) throws Exception {
    final Command<Object> command = (Command<Object>) WireContext.create(this.commandDescriptor);
    command.execute(environment);

    final JobDbSession jobDbSession = environment.get(JobDbSession.class);
    jobDbSession.delete(this);
    return null;
  }

}

==> orchestra-pvm-4.4.1-sources.jar: org/ow2/orchestra/pvm/internal/job/CommandMessage.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.ow2.orchestra.pvm.internal.job;

import org.ow2.orchestra.pvm.env.Environment;
import org.ow2.orchestra.pvm.internal.cmd.Command;
import org.ow2.orchestra.pvm.internal.jobexecutor.JobDbSession;
import org.ow2.orchestra.pvm.internal.wire.Descriptor;
import org.ow2.orchestra.pvm.internal.wire.WireContext;

/**
 * @author Tom Baeyens
 */
public class CommandMessage extends MessageImpl<Object> {

  private static final long serialVersionUID = 1L;

  public CommandMessage() {
  }

  public CommandMessage(final Descriptor commandDescriptor) {
    this.commandDescriptor = commandDescriptor;
  }

  public Object execute(final Environment environment) {
    final Command<Object> command = (Command<Object>) WireContext.create(this.commandDescriptor);
    command.execute(environment);

    final JobDbSession jobDbSession = environment.get(JobDbSession.class);
    jobDbSession.delete(this);
    return null;
  }

}
